searchData={"content_type":"text/markdown","items":[{"doc":"For example usage please refer to [test/examples](https://github.com/highmobility/telemetry_test/tree/main/test/examples) directory","ref":"TelemetryTest.html","title":"TelemetryTest","type":"module"},{"doc":"ExUnit setup callback function which attaches to telemetry events","ref":"TelemetryTest.html#telemetry_listen/1","title":"TelemetryTest.telemetry_listen/1","type":"function"},{"doc":"# Telemetry Test\n\nTelemetry Test is an Elixir library designed to simplify and reduce test clutter when testing Telemetry events. It provides a convenient way to set up Telemetry event listeners, enabling you to write cleaner and more expressive tests for your Telemetry-powered applications.","ref":"readme.html","title":"Telemetry Test","type":"extras"},{"doc":"Telemetry is a powerful framework in Elixir that allows you to instrument your code and collect valuable runtime data. However, when it comes to testing Telemetry events, the process can become verbose and cluttered, leading to complex test code and reduced readability. This library aims to address this challenge by providing a set of utilities that streamline the testing process, making it easier and more enjoyable.","ref":"readme.html#introduction","title":"Introduction - Telemetry Test","type":"extras"},{"doc":"#","ref":"readme.html#key-features","title":"Key Features - Telemetry Test","type":"extras"},{"doc":"You can set up Telemetry event listeners with just a few lines of code. Instead of manually attaching and detaching event handlers, the library provides functions that handle this process automatically, reducing boilerplate code in your tests.\n\n#","ref":"readme.html#simplified-event-setup","title":"Simplified Event Setup - Telemetry Test","type":"extras"},{"doc":"By abstracting away the setup for Telemetry events, it significantly reduces test clutter. Your test code becomes cleaner, more focused, and easier to understand, improving maintainability and reducing the cognitive load when working with Telemetry-based tests.\n\n#","ref":"readme.html#reduced-test-clutter","title":"Reduced Test Clutter - Telemetry Test","type":"extras"},{"doc":"It supports various options for listening to Telemetry events. You can listen for specific events using using the event names, match events with custom callbacks and even listen to multiple events.","ref":"readme.html#multiple-event-listening-options","title":"Multiple Event Listening Options - Telemetry Test","type":"extras"},{"doc":"To start using the Telemetry Test Helper in your Elixir project, follow these steps:\n\n1. Add the `telemetry_test_helper` dependency to your `mix.exs` file:\n\n```elixir\ndefp deps do\n  [\n    {:telemetry_test, \"~> 1.0\"}\n  ]\nend\n```\n\n2. Run `mix deps.get` to fetch the new dependency.\n\n3. Ensure that the Telemetry events you want to test are properly instrumented in your application or library.\n\n4. In your test module or TestCase, import the necessary functions from the library:\n\n```elixir\ndefmodule MyTestModule do\n  use ExUnit.Case, async: false\n  import TelemetryTest\nend\n```\n\n5. Write your tests by utilizing the library functions. Set up event listeners and perform assertions on received events to validate the behavior of your code.\n\n```elixir\ndefmodule MyTestModule do\n  use ExUnit.Case, async: false\n  import TelemetryTest\n\n  setup [:telemetry_listen]\n\n  @tag telemetry_listen: [:sample, :event, :example_one]\n  test \"match on telemetry event\" do\n    # Execute the code that will emit the telemetry event\n    assert :there = ExampleOne.hello()\n\n    # your test process will receive a message with Telemetry event\n    assert_receive {:telemetry_event,\n                    %{\n                      event: [:sample, :event, :example_one],\n                      measurements: %{sample_value: :hello_there},\n                      metadata: %{sample_metadata: true}\n                    }}\n  end\nend\n```\n\n6. Run your tests with `mix test` and observe the improved clarity and simplicity in your Telemetry event tests.","ref":"readme.html#getting-started","title":"Getting Started - Telemetry Test","type":"extras"},{"doc":"To help you understand how to use the Telemetry Test, we provide a collection of examples in the [Telemetry Test GitHub repository](https://github.com/highmobility/telemetry_test/tree/main/test/examples). These examples demonstrate different scenarios and use cases, showcasing the capabilities of the library and providing practical guidance for writing effective Telemetry event tests.","ref":"readme.html#examples","title":"Examples - Telemetry Test","type":"extras"}]}